local categoryStates = {"Questing", "Dungeons", "Raids"}

local minimapIconButton = CreateFrame("Button", "LazyGroupFinderMinimapIcon", Minimap)
minimapIconButton:SetPoint("RIGHT")
minimapIconButton:SetSize(33, 33)
minimapIconButton:SetMovable(true)
minimapIconButton:EnableMouse(true)
minimapIconButton:SetFrameStrata("HIGH")
minimapIconButton:SetFrameLevel(8)
minimapIconButton:SetClampedToScreen(true)
minimapIconButton:SetDontSavePosition()
minimapIconButton:RegisterForClicks("LeftButtonUp", "RightButtonUp")
minimapIconButton:RegisterForDrag("LeftButton", "RightButton")
minimapIconButton:EnableDrawLayer("BACKGROUND")
minimapIconButton:EnableDrawLayer("OVERLAY")

local normalTexture = minimapIconButton:CreateTexture("PGF_minimapButton_BackgroundTexture", "BACKGROUND")
normalTexture:SetDrawLayer("BACKGROUND", 0)
normalTexture:SetTexture("Interface\\addons\\PGFinder\\disabled.tga")
normalTexture:SetSize(21,21)
normalTexture:SetPoint("TOPLEFT", 6, -5)

local highlightTexture = minimapIconButton:CreateTexture("PGF_minimapButton_OverlayTexture", "OVERLAY")
highlightTexture:SetTexture("Interface\\Minimap\\MiniMap-TrackingBorder")
highlightTexture:SetSize(56,56)
highlightTexture:SetPoint("TOPLEFT")

minimapIconButton:SetScript("OnClick", function(self)
	if self.dragging then
		self:SetScript("OnUpdate", nil)
	end
	local button = GetMouseButtonClicked()
	if button == "RightButton" then
		InterfaceOptionsFrame_OpenToCategory(LazyGroupFinderOptions)
		if not LazyGroupFinderOptions:IsVisible() then
			InterfaceOptionsFrame_OpenToCategory(LazyGroupFinderOptions)
		end
	elseif button == "LeftButton" then
		if LazyGroupFinderEnabled then
			LazyGroupFinderDisableAddon()
			PlaySound("igMainMenuOptionCheckBoxOff")
		else
			LazyGroupFinderEnableAddon()
			PlaySound("igMainMenuOptionCheckBoxOn")
		end
	end
end)
minimapIconButton:SetScript("OnDragStart", function(self)
	self:LockHighlight()
	self.dragging = true
	self:SetScript("OnUpdate", function(self)
		if not IsMouseButtonDown() then
			self:SetScript("OnUpdate", nil)
			self.dragging = false
		end
		local xpos,ypos = GetCursorPosition()
		local xmin,xmax,ymin,ymax = Minimap:GetLeft(), Minimap:GetRight(), Minimap:GetBottom(), Minimap:GetTop()
		local xLen = xmax-xmin
		local yLen = ymax-ymin

		xpos = xmin-xpos/UIParent:GetScale()+(xLen/2) -- get coordinates as differences from the center of the minimap
		ypos = ypos/UIParent:GetScale()-ymin-(yLen/2)

		PGF_minimapDegree = math.deg(math.atan2(ypos,xpos)) -- save the degrees we are relative to the minimap center
		LazyGroupFinder_MinimapButton_SetPoint(PGF_minimapDegree)
	end)
end)
minimapIconButton:SetScript("OnDragStop", function(self)
	self:LockHighlight()
	self.dragging = false
	self:SetScript("OnUpdate", nil)
end)
minimapIconButton:SetScript("OnEnter", function(self)
	GameTooltip:SetOwner(self, "ANCHOR_BOTTOMLEFT")
	if LazyGroupFinderEnabled then
		GameTooltip:SetText("|cFF00FF00Lazy Group Finder")
	else
		GameTooltip:SetText("|cFFFF0000Lazy Group Finder")
	end
	local nrofactivities = 0
	local results = C_LFGList.GetAvailableActivities(LazyGroupFinderActivityType, nil, 1)
	for k,v in pairs(results) do
		if LazyGroupFinderActivities[v] == nil then LazyGroupFinderActivities[v] = false end
		if LazyGroupFinderActivities[v] then nrofactivities = 1 + nrofactivities end
	end
	GameTooltip:AddLine("|cFFFFFFFF" .. categoryStates[LazyGroupFinderActivityType] .. " (" .. nrofactivities .. ")")
	if LazyGroupFinderEnabled then
		GameTooltip:AddLine("Leftclick: Disable")
	else
		GameTooltip:AddLine("Leftclick: Enable")
	end
	GameTooltip:AddLine("Rightclick: Options")
	GameTooltip:Show()
end)
minimapIconButton:SetScript("OnLeave", function(self)
	GameTooltip:Hide()
end)

function LazyGroupFinder_MinimapButton_SetEnabled(self)
	normalTexture:SetTexture("Interface\\addons\\LazyGroupFinder\\enabled.tga")
end
function LazyGroupFinder_MinimapButton_SetDisabled(self)
	normalTexture:SetTexture("Interface\\addons\\LazyGroupFinder\\disabled.tga")
end

function LazyGroupFinder_MinimapButton_SetPoint(degree)
	LazyGroupFinderMinimapIconPoint = degree
	LazyGroupFinderMinimapIcon:ClearAllPoints()
	LazyGroupFinderMinimapIcon:SetPoint("TOPLEFT", "Minimap","TOPLEFT",52-(80*cos(degree)),(80*sin(degree))-52)
end