LazyGroupFinderOptions = CreateFrame("Frame", "LazyGroupFinderOptions", InterefaceOptionsFramePanelContainer)
LazyGroupFinderOptions.name = "Lazy Group Finder"
LazyGroupFinderOptions:Hide()

local categoryStates = {"Questing", "Dungeons", "Raids"}
local activityStates = {}
local selectedNrOfActivities = 0

-- ADDON NAME
local addonNameText = LazyGroupFinderOptions:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge")
addonNameText:SetPoint("TOPLEFT", 32, -32)
addonNameText:SetText("Lazy Group Finder")

-- ENABLED CHECKBOX
local enabledButton = CreateFrame("CheckButton", "LazyGroupFinderEnabledCheckButton", LazyGroupFinderOptions, "OptionsCheckButtonTemplate")
enabledButton:SetSize(26, 26)
enabledButton:SetPoint("TOPLEFT", 32, -55)
enabledButton:HookScript("OnClick", function(self)
	if self:GetChecked() then
		LazyGroupFinderEnabled = true
		PlaySound("igMainMenuOptionCheckBoxOn")
	else
		LazyGroupFinderEnabled = false
		PlaySound("igMainMenuOptionCheckBoxOff")
	end
end)

local enabledText = LazyGroupFinderOptions:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
enabledText:SetPoint("TOPLEFT", enabledButton, "TOPLEFT", 30, -7)
enabledText:SetText("Enabled")

-- ACTIVITIES
local activityText = LazyGroupFinderOptions:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
activityText:SetPoint("TOPLEFT", 282, -95)
activityText:SetText("Activity:")

local activityStateMenu = CreateFrame("Button", "LazyGroupFinderActivityStateMenu", LazyGroupFinderOptions, "UIDropDownMenuTemplate")
activityStateMenu:SetPoint("TOPLEFT", activityText, "BOTTOMLEFT", 0, -5)
local function Initialize_ActivityStateMenu(self, level)
	local info = UIDropDownMenu_CreateInfo()
	selectedNrOfActivities = 0
	for k,v in pairs(activityStates) do
		local activityName,_,activityType,_,_,_,_,_,_,_ = C_LFGList.GetActivityInfo(k)
		info = UIDropDownMenu_CreateInfo()
		info.text = activityName
		info.value = k
		info.checked = v
		info.func = activityState_OnClick
		info.isNotRadio = true
		info.keepShownOnClick = true
		UIDropDownMenu_AddButton(info, level)
		if v then selectedNrOfActivities = selectedNrOfActivities + 1 end
	end
	UIDropDownMenu_SetText(activityStateMenu, "Filter (" .. selectedNrOfActivities .. ")")
end

function activityState_OnClick(self)
	LazyGroupFinderActivities[self.value] = not LazyGroupFinderActivities[self.value]
	activityStates[self.value] = LazyGroupFinderActivities[self.value]
	if activityStates[self.value] then selectedNrOfActivities = selectedNrOfActivities + 1 end
	if not activityStates[self.value] then selectedNrOfActivities = selectedNrOfActivities - 1 end
	UIDropDownMenu_SetText(activityStateMenu, "Filter (" .. selectedNrOfActivities .. ")")
end

UIDropDownMenu_SetWidth(activityStateMenu, 130)
UIDropDownMenu_SetButtonWidth(activityStateMenu, 130)
UIDropDownMenu_JustifyText(activityStateMenu, "CENTER")
UIDropDownMenu_Initialize(activityStateMenu, Initialize_ActivityStateMenu)

-- CATEGORY
local categoryText = LazyGroupFinderOptions:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
categoryText:SetPoint("TOPLEFT", 42, -95)
categoryText:SetText("Category:")

local categoryStateMenu = CreateFrame("Button", "LazyGroupFinderCategoryStateMenu", LazyGroupFinderOptions, "UIDropDownMenuTemplate")
categoryStateMenu:SetPoint("TOPLEFT", categoryText, "BOTTOMLEFT", 0, -5)
local function Initialize_CategoryStateMenu(self, level)
	local info = UIDropDownMenu_CreateInfo()
	for k,v in pairs(categoryStates) do
		info = UIDropDownMenu_CreateInfo()
		info.text = v
		info.value = k
		info.func = categoryState_OnClick
		UIDropDownMenu_AddButton(info, level)
	end
end

function categoryState_OnClick(self)
	UIDropDownMenu_SetSelectedID(categoryStateMenu, self:GetID())
	LazyGroupFinderActivityType = self.value
	activityStates = {}
	local results = C_LFGList.GetAvailableActivities(LazyGroupFinderActivityType, nil, 1)
	for k,v in pairs(results) do
		if LazyGroupFinderActivities[v] == nil then LazyGroupFinderActivities[v] = false end
		activityStates[v] = LazyGroupFinderActivities[v]
	end
	Initialize_ActivityStateMenu()
end

UIDropDownMenu_SetWidth(categoryStateMenu, 130)
UIDropDownMenu_SetButtonWidth(categoryStateMenu, 130)
UIDropDownMenu_JustifyText(categoryStateMenu, "CENTER")
UIDropDownMenu_Initialize(categoryStateMenu, Initialize_CategoryStateMenu)

-- KEYWORDS
local keywordsText = LazyGroupFinderOptions:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
keywordsText:SetPoint("TOPLEFT", 42, -155)
keywordsText:SetText("Filter keywords:")

local keywordsDESCText = LazyGroupFinderOptions:CreateFontString(nil, "ARTWORK", "GameFontDisable")
keywordsDESCText:SetPoint("LEFT", keywordsText, "RIGHT", 20, 0)
keywordsDESCText:SetText("for Name, Description or Leader (one must match)")

local keywordsEditBox = CreateFrame("EditBox", "LazyGroupFinderKeywordsEditBox", LazyGroupFinderOptions, "InputBoxTemplate")
keywordsEditBox:SetPoint("TOPLEFT", keywordsText, "BOTTOMLEFT", 20, -5)
keywordsEditBox:SetAutoFocus(false)
keywordsEditBox:SetSize(300, 25)
keywordsEditBox:SetText("")
keywordsEditBox:SetScript("OnEscapePressed", function (self)
	self:ClearFocus()
	LazyGroupFinderKeywords = keywordsEditBox:GetText()
end)
keywordsEditBox:SetScript("OnEnterPressed", function(self)
	self:ClearFocus()
	LazyGroupFinderKeywords = keywordsEditBox:GetText()
end)

-- IGNORE WORDS
local bannedwordsText = LazyGroupFinderOptions:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
bannedwordsText:SetPoint("TOPLEFT", 42, -205)
bannedwordsText:SetText("Banned keywords:")

local bannedwordsDESCText = LazyGroupFinderOptions:CreateFontString(nil, "ARTWORK", "GameFontDisable")
bannedwordsDESCText:SetPoint("LEFT", bannedwordsText, "RIGHT", 20, 0)
bannedwordsDESCText:SetText("for Name, Description or Leader (none can match)")

local bannedwordsEditBox = CreateFrame("EditBox", "LazyGroupFinderBannedwordsEditBox", LazyGroupFinderOptions, "InputBoxTemplate")
bannedwordsEditBox:SetPoint("TOPLEFT", bannedwordsText, "BOTTOMLEFT", 20, -5)
bannedwordsEditBox:SetAutoFocus(false)
bannedwordsEditBox:SetSize(300, 25)
bannedwordsEditBox:SetText("")
bannedwordsEditBox:SetScript("OnEscapePressed", function (self)
	self:ClearFocus()
	LazyGroupFinderBannedwords = bannedwordsEditBox:GetText()
end)
bannedwordsEditBox:SetScript("OnEnterPressed", function(self)
	self:ClearFocus()
	LazyGroupFinderBannedwords = bannedwordsEditBox:GetText()
end)

-- BONUS NAME
local bonusNameText = LazyGroupFinderOptions:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge")
bonusNameText:SetPoint("TOPLEFT", 32, -272)
bonusNameText:SetText("Bonus Features")

-- ACHIEVEMENT ON WHISPER
local achievementButton = CreateFrame("CheckButton", "LazyGroupFinderAchievementCheckButton", LazyGroupFinderOptions, "OptionsCheckButtonTemplate")
achievementButton:SetSize(26, 26)
achievementButton:SetPoint("TOPLEFT", 32, -295)
achievementButton:HookScript("OnClick", function(self)
	if self:GetChecked() then
		LazyGroupFinderAchievementOnApply = true
		PlaySound("igMainMenuOptionCheckBoxOn")
	else
		LazyGroupFinderAchievementOnApply = false
		PlaySound("igMainMenuOptionCheckBoxOff")
	end
end)

local achievementText = LazyGroupFinderOptions:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
achievementText:SetPoint("TOPLEFT", achievementButton, "TOPLEFT", 30, -7)
achievementText:SetText("Auto whisper achievement")

-- ON SHOW
LazyGroupFinderOptions:SetScript("OnShow", function(...)
	enabledButton:SetChecked(LazyGroupFinderEnabled)
	Initialize_CategoryStateMenu()
	UIDropDownMenu_SetSelectedName(categoryStateMenu, categoryStates[LazyGroupFinderActivityType])
	activityStates = {}
	local results = C_LFGList.GetAvailableActivities(LazyGroupFinderActivityType, nil, 1)
	for k,v in pairs(results) do
		if LazyGroupFinderActivities[v] == nil then LazyGroupFinderActivities[v] = false end
		activityStates[v] = LazyGroupFinderActivities[v]
	end
	Initialize_ActivityStateMenu()
	keywordsEditBox:SetText(LazyGroupFinderKeywords)
	bannedwordsEditBox:SetText(LazyGroupFinderBannedwords)
	achievementButton:SetChecked(LazyGroupFinderAchievementOnApply)
end)

InterfaceOptions_AddCategory(LazyGroupFinderOptions)
